@@ -34,11 +34,15 @@ __all__ = (
     "RecommendationFeedbackSummaryTypeDef",
     "RecommendationFeedbackTypeDef",
     "RecommendationSummaryTypeDef",
+    "RepositoryAnalysisTypeDef",
     "RepositoryAssociationSummaryTypeDef",
     "RepositoryAssociationTypeDef",
+    "RepositoryHeadSourceCodeTypeTypeDef",
     "SourceCodeTypeTypeDef",
     "ThirdPartySourceRepositoryTypeDef",
     "AssociateRepositoryResponseTypeDef",
+    "CodeReviewTypeTypeDef",
+    "CreateCodeReviewResponseTypeDef",
     "DescribeCodeReviewResponseTypeDef",
     "DescribeRecommendationFeedbackResponseTypeDef",
     "DescribeRepositoryAssociationResponseTypeDef",
@@ -64,7 +68,7 @@ CodeReviewSummaryTypeDef = TypedDict(
         "State": Literal["Completed", "Pending", "Failed", "Deleting"],
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest"],
+        "Type": Literal["PullRequest", "RepositoryAnalysis"],
         "PullRequestId": str,
         "MetricsSummary": "MetricsSummaryTypeDef",
     },
@@ -83,7 +87,7 @@ CodeReviewTypeDef = TypedDict(
         "StateReason": str,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
-        "Type": Literal["PullRequest"],
+        "Type": Literal["PullRequest", "RepositoryAnalysis"],
         "PullRequestId": str,
         "SourceCodeType": "SourceCodeTypeTypeDef",
         "Metrics": "MetricsTypeDef",
@@ -134,6 +138,10 @@ RecommendationSummaryTypeDef = TypedDict(
     total=False,
 )
 
+RepositoryAnalysisTypeDef = TypedDict(
+    "RepositoryAnalysisTypeDef", {"RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef"}
+)
+
 RepositoryAssociationSummaryTypeDef = TypedDict(
     "RepositoryAssociationSummaryTypeDef",
     {
@@ -166,8 +174,17 @@ RepositoryAssociationTypeDef = TypedDict(
     total=False,
 )
 
+RepositoryHeadSourceCodeTypeTypeDef = TypedDict(
+    "RepositoryHeadSourceCodeTypeTypeDef", {"BranchName": str}
+)
+
 SourceCodeTypeTypeDef = TypedDict(
-    "SourceCodeTypeTypeDef", {"CommitDiff": "CommitDiffSourceCodeTypeTypeDef"}, total=False
+    "SourceCodeTypeTypeDef",
+    {
+        "CommitDiff": "CommitDiffSourceCodeTypeTypeDef",
+        "RepositoryHead": "RepositoryHeadSourceCodeTypeTypeDef",
+    },
+    total=False,
 )
 
 ThirdPartySourceRepositoryTypeDef = TypedDict(
@@ -180,6 +197,14 @@ AssociateRepositoryResponseTypeDef = TypedDict(
     total=False,
 )
 
+CodeReviewTypeTypeDef = TypedDict(
+    "CodeReviewTypeTypeDef", {"RepositoryAnalysis": "RepositoryAnalysisTypeDef"}
+)
+
+CreateCodeReviewResponseTypeDef = TypedDict(
+    "CreateCodeReviewResponseTypeDef", {"CodeReview": "CodeReviewTypeDef"}, total=False
+)
+
 DescribeCodeReviewResponseTypeDef = TypedDict(
     "DescribeCodeReviewResponseTypeDef", {"CodeReview": "CodeReviewTypeDef"}, total=False
 )
